@@ -74,25 +74,34 @@ class AsyncFlowClient(AsyncBaseClient):
 
     @if_alive
     async def update(
-        self, id: Union[str, 'DaemonID'], pod_name: str, dump_path: str, *args, **kwargs
+        self,
+        id: Union[str, 'DaemonID'],
+        pod_name: str,
+        dump_path: Optional[str] = None,
+        *,
+        uses_with: Optional[Dict] = None,
     ) -> str:
         """Update a Flow on remote JinaD (only rolling_update supported)
 
         :param id: flow id
         :param pod_name: pod name for rolling update
         :param dump_path: path of dump from other flow
-        :param args: positional args
-        :param kwargs: keyword args
+        :param uses_with: the uses with to override the Executors params
         :return: flow id
         """
+        if dump_path is not None:
+            if uses_with is not None:
+                uses_with['dump_path'] = dump_path
+            else:
+                uses_with = {'dump_path': dump_path}
         async with aiohttp.request(
             method='PUT',
             url=f'{self.store_api}/{daemonize(id, self._kind)}',
             params={
                 'kind': UpdateOperation.ROLLING_UPDATE.value,
                 'pod_name': pod_name,
-                'dump_path': dump_path,
             },
+            json=uses_with,
             timeout=self.timeout,
         ) as response:
             response_json = await response.json()
