@@ -18,8 +18,14 @@ from .helper import (
     upload_file,
     disk_cache_offline,
 )
-from .helper import install_requirements
-from .hubapi import install_local, resolve_local, load_secret, dump_secret, get_lockfile
+from .hubapi import (
+    install_local,
+    get_dist_path_of_executor,
+    load_secret,
+    dump_secret,
+    get_lockfile,
+    install_package_dependencies,
+)
 from .. import __resources_path__
 from ..helper import get_full_version, ArgNamespace
 from ..importer import ImportExtensions
@@ -61,13 +67,6 @@ class HubIO:
             assert cryptography
             assert filelock
 
-    def _load_docker_client(self):
-        with ImportExtensions(required=True):
-            import docker
-            from docker import DockerClient
-
-            self._client: DockerClient = docker.from_env()
-
     @staticmethod
     def _get_request_header() -> Dict:
         """Return the header of request.
@@ -98,86 +97,92 @@ class HubIO:
         print(
             Panel.fit(
                 '''
-[bold green]Executor[/bold green] is how Jina processes [bold]Document[/bold]. 
+[bold green]Executor[/bold green] is how Jina processes [bold]Document[/bold].
 
 This guide helps you to create your own Executor in 30 seconds.''',
                 title='Create New Executor',
             )
         )
 
-        exec_name = Prompt.ask(
-            ':grey_question: What is the [bold]name[/bold] of your executor?\n'
-            '[dim]CamelCase is required[/dim]',
-            default=f'MyExecutor{random.randint(0, 100)}',
+        exec_name = (
+            self.args.name
+            if self.args.name
+            else Prompt.ask(
+                ':grey_question: What is the [bold]name[/bold] of your executor?\n'
+                '[dim]CamelCase is required[/dim]',
+                default=f'MyExecutor{random.randint(0, 100)}',
+            )
         )
 
-        exec_path = Prompt.ask(
-            ':grey_question: [bold]Which folder[/bold] to store your executor?',
-            default=os.path.join(os.getcwd(), exec_name),
+        exec_path = (
+            self.args.path
+            if self.args.path
+            else Prompt.ask(
+                ':grey_question: [bold]Which folder[/bold] to store your executor?',
+                default=os.path.join(os.getcwd(), exec_name),
+            )
         )
-
         exec_description = '{{}}'
         exec_keywords = '{{}}'
-        exec_author = '{{}}'
         exec_url = '{{}}'
 
         is_dockerfile = False
 
-        if Confirm.ask(
+        if self.args.advance_configuration or Confirm.ask(
             '[green]That\'s all we need to create an Executor![/green]\n'
             ':grey_question: Or do you want to proceed to advanced configuration',
             default=False,
         ):
             exec_description = (
-                Prompt.ask(
-                    ':grey_question: Please give a [bold]short description[/bold] of your executor?\n'
-                    f'[dim]Example: {exec_name} embeds images into 128-dim vectors using ResNet.[/dim]'
+                self.args.description
+                if self.args.description
+                else (
+                    Prompt.ask(
+                        ':grey_question: Please give a [bold]short description[/bold] of your executor?\n'
+                        f'[dim]Example: {exec_name} embeds images into 128-dim vectors using ResNet.[/dim]'
+                    )
                 )
-                or exec_description
-            )
-
-            exec_author = (
-                Prompt.ask(
-                    ':grey_question: What is the [bold]author name[/bold]?\n'
-                    f'[dim]Example: John Doe[/dim]'
-                )
-                or exec_author
             )
 
             exec_keywords = (
-                Prompt.ask(
-                    ':grey_question: Please give some [bold]keywords[/bold] to help people search your executor [dim](separated by space)[/dim]\n'
-                    f'[dim]Example: image cv embedding encoding resnet[/dim]'
+                self.args.keywords
+                if self.args.keywords
+                else (
+                    Prompt.ask(
+                        ':grey_question: Please give some [bold]keywords[/bold] to help people search your executor [dim](separated by comma)[/dim]\n'
+                        f'[dim]Example: image cv embedding encoding resnet[/dim]'
+                    )
                 )
-                or exec_keywords
             )
 
             exec_url = (
-                Prompt.ask(
-                    ':grey_question: What is the [bold]URL[/bold] for documentation/reference/more info?\n'
-                    f'[dim]Example: https://docs.jina.ai[/dim]'
+                self.args.url
+                if self.args.url
+                else (
+                    Prompt.ask(
+                        ':grey_question: What is the [bold]URL[/bold] for GitHub repo?\n'
+                        f'[dim]Example: https://github.com/yourname/my-executor[/dim]'
+                    )
                 )
-                or exec_url
             )
 
             print(
                 Panel.fit(
                     '''
-[bold]Dockerfile[/bold] describes how this executor will be built. It is useful when 
-your executor has non-trivial dependencies or must be run under certain environment. 
+[bold]Dockerfile[/bold] describes how this executor will be built. It is useful when
+your executor has non-trivial dependencies or must be run under certain environment.
 
-- If the [bold]Dockerfile[/bold] is missing, Jina automatically generates one for you. 
+- If the [bold]Dockerfile[/bold] is missing, Jina automatically generates one for you.
 - If you provide one, then Jina will respect the given [bold]Dockerfile[/bold].''',
                     title='[Optional] [bold]Dockerfile[/bold]',
                     width=80,
                 )
             )
 
-            is_dockerfile = Confirm.ask(
+            is_dockerfile = self.args.add_dockerfile or Confirm.ask(
                 ':grey_question: Do you need to write your own [bold]Dockerfile[/bold] instead of the auto-generated one?',
                 default=False,
             )
-
             print('[green]That\'s all we need to create an Executor![/green]')
 
         def mustache_repl(srcs):
@@ -191,8 +196,7 @@ your executor has non-trivial dependencies or must be run under certain environm
                         fp.read()
                         .replace('{{exec_name}}', exec_name)
                         .replace('{{exec_description}}', exec_description)
-                        .replace('{{exec_keywords}}', exec_keywords)
-                        .replace('{{exec_author}}', exec_author)
+                        .replace('{{exec_keywords}}', str(exec_keywords.split(',')))
                         .replace('{{exec_url}}', exec_url)
                     )
 
@@ -219,11 +223,12 @@ your executor has non-trivial dependencies or must be run under certain environm
         table.add_column('Filename', style='cyan', no_wrap=True)
         table.add_column('Description', no_wrap=True)
 
-        table.add_row('executor.py', 'The main logic file of the Executor.')
+        # adding the columns in order of `ls` output
         table.add_row(
             'config.yml',
             'The YAML config file of the Executor. You can define [bold]__init__[/bold] arguments using [bold]with[/bold] keyword.',
         )
+
         table.add_row(
             '',
             Panel(
@@ -233,8 +238,9 @@ jtype: {exec_name}
 with:
     foo: 1
     bar: hello
-py_modules:
-    - executor.py
+metas:
+    py_modules:
+        - executor.py
                 ''',
                     'yaml',
                     theme='monokai',
@@ -246,24 +252,6 @@ py_modules:
                 expand=False,
             ),
         )
-        table.add_row('README.md', 'The usage of the Executor.')
-        table.add_row('requirements.txt', 'The Python dependencies of the Executor.')
-        table.add_row(
-            'manifest.yml',
-            'The annotations of the Executor for getting better appealing on Jina Hub.',
-        )
-
-        field_table = Table(box=box.SIMPLE)
-        field_table.add_column('Field', style='cyan', no_wrap=True)
-        field_table.add_column('Description', no_wrap=True)
-        field_table.add_row('name', 'Human-readable title of the Executor')
-        field_table.add_row('alias', 'The unique identifier in Jina Hub')
-        field_table.add_row('description', 'Human-readable description of the Executor')
-        field_table.add_row('author', 'The author of the Executor')
-        field_table.add_row('url', 'URL to find more information on the Executor')
-        field_table.add_row('keywords', 'Keywords that help user find the Executor')
-
-        table.add_row('', field_table)
 
         if is_dockerfile:
             table.add_row(
@@ -271,6 +259,31 @@ py_modules:
                 'The Dockerfile describes how this executor will be built.',
             )
 
+        table.add_row('executor.py', 'The main logic file of the Executor.')
+        table.add_row(
+            'manifest.yml',
+            'Metadata for the Executor, for better appeal on Jina Hub.',
+        )
+
+        manifest_fields_table = Table(box=box.SIMPLE)
+        manifest_fields_table.add_column('Field', style='cyan', no_wrap=True)
+        manifest_fields_table.add_column('Description', no_wrap=True)
+        manifest_fields_table.add_row('name', 'Human-readable title of the Executor')
+        manifest_fields_table.add_row(
+            'description', 'Human-readable description of the Executor'
+        )
+        manifest_fields_table.add_row(
+            'url',
+            'URL to find more information on the Executor (e.g. GitHub repo URL)',
+        )
+        manifest_fields_table.add_row(
+            'keywords', 'Keywords that help user find the Executor'
+        )
+
+        table.add_row('', manifest_fields_table)
+        table.add_row('README.md', 'A usage guide of the Executor.')
+        table.add_row('requirements.txt', 'The Python dependencies of the Executor.')
+
         final_table = Table(box=None)
 
         final_table.add_row(
@@ -285,14 +298,14 @@ py_modules:
                 line_numbers=True,
                 word_wrap=True,
             ),
-            title='1. Checkout the Generated Executor',
+            title='1. Check out the generated Executor',
             width=120,
             expand=False,
         )
 
         p1 = Panel(
             table,
-            title='2. Understand Folder Structure',
+            title='2. Understand folder structure',
             width=120,
             expand=False,
         )
@@ -316,7 +329,7 @@ py_modules:
 
         p = Panel(
             final_table,
-            title=':tada: Next Steps',
+            title=':tada: Next steps',
             width=130,
             expand=False,
         )
@@ -327,13 +340,31 @@ py_modules:
 
         from rich.console import Console
 
+        work_path = Path(self.args.path)
+
+        exec_tags = None
+        if self.args.tag:
+            exec_tags = ','.join(self.args.tag)
+
+        dockerfile = None
+        if self.args.dockerfile:
+            dockerfile = Path(self.args.dockerfile)
+            if not dockerfile.exists():
+                raise Exception(f'The given Dockerfile `{dockerfile}` does not exist!')
+            if dockerfile.parent != work_path:
+                raise Exception(
+                    f'The Dockerfile must be placed at the given folder `{work_path}`'
+                )
+
+            dockerfile = dockerfile.relative_to(work_path)
+
         console = Console()
-        with console.status(f'Pushing `{self.args.path}`...') as st:
+        with console.status(f'Pushing `{self.args.path}` ...') as st:
             req_header = self._get_request_header()
             try:
-                st.update(f'Packaging {self.args.path}...')
+                st.update(f'Packaging {self.args.path} ...')
                 md5_hash = hashlib.md5()
-                bytesio = archive_package(Path(self.args.path))
+                bytesio = archive_package(work_path)
                 content = bytesio.getvalue()
                 md5_hash.update(content)
                 md5_digest = md5_hash.hexdigest()
@@ -346,18 +377,25 @@ py_modules:
                     else 'False',
                     'md5sum': md5_digest,
                 }
-                uuid8, secret = load_secret(Path(self.args.path))
-                if self.args.force or uuid8:
-                    form_data['force'] = self.args.force or uuid8
+
+                if exec_tags:
+                    form_data['tags'] = exec_tags
+
+                if dockerfile:
+                    form_data['dockerfile'] = str(dockerfile)
+
+                uuid8, secret = load_secret(work_path)
+                if self.args.force_update or uuid8:
+                    form_data['force'] = self.args.force_update or uuid8
                 if self.args.secret or secret:
                     form_data['secret'] = self.args.secret or secret
 
                 method = 'put' if ('force' in form_data) else 'post'
 
-                st.update(f'Connecting Hubble...')
+                st.update(f'Connecting to Jina Hub ...')
                 hubble_url = get_hubble_url()
-                # upload the archived executor to Jina Hub
 
+                # upload the archived executor to Jina Hub
                 st.update(f'Uploading...')
                 resp = upload_file(
                     hubble_url,
@@ -372,8 +410,15 @@ py_modules:
                 result = None
                 for stream_line in resp.iter_lines():
                     stream_msg = json.loads(stream_line)
+
                     if 'stream' in stream_msg:
-                        st.update(stream_msg['stream'])
+                        st.update(
+                            f'Cloud building ... [dim]{stream_msg["stream"]}[/dim]'
+                        )
+                    elif 'status' in stream_msg:
+                        st.update(
+                            f'Cloud building ... [dim]{stream_msg["status"]}[/dim]'
+                        )
                     elif 'result' in stream_msg:
                         result = stream_msg['result']
                         break
@@ -385,7 +430,7 @@ py_modules:
                 elif 200 <= result['statusCode'] < 300:
                     new_uuid8, new_secret = self._prettyprint_result(console, result)
                     if new_uuid8 != uuid8 or new_secret != secret:
-                        dump_secret(Path(self.args.path), new_uuid8, new_secret)
+                        dump_secret(work_path, new_uuid8, new_secret)
                 elif result['message']:
                     raise Exception(result['message'])
                 elif resp.text:
@@ -394,6 +439,9 @@ py_modules:
                 else:
                     resp.raise_for_status()
 
+            except KeyboardInterrupt:
+                pass
+
             except Exception as e:  # IO related errors
                 self.logger.error(
                     f'Error while pushing session_id={req_header["jinameta-session-id"]}: '
@@ -405,66 +453,73 @@ py_modules:
         # TODO: only support single executor now
 
         from rich.table import Table
-        from rich import box
+        from rich.panel import Panel
 
         data = result.get('data', None)
         image = data['executors'][0]
         uuid8 = image['id']
         secret = image['secret']
         visibility = image['visibility']
+        tag = self.args.tag[0] if self.args.tag else None
 
-        table = Table(box=box.SIMPLE)
-        table.add_column('Key', no_wrap=True)
-        table.add_column('Value', style='cyan', no_wrap=True)
-        table.add_row(':key: ID', uuid8)
-        if 'alias' in image:
-            table.add_row(':name_badge: Alias', image['alias'])
+        table = Table.grid()
+        table.add_column(width=20, no_wrap=True)
+        table.add_column(style='cyan', no_wrap=True)
+        table.add_row(
+            ':link: Hub URL',
+            f'[link=https://hub.jina.ai/executor/{uuid8}/]https://hub.jina.ai/executor/{uuid8}/[/link]',
+        )
+        if 'name' in image:
+            table.add_row(':name_badge: Name', image['name'])
         table.add_row(':lock: Secret', secret)
         table.add_row(
             '',
             ':point_up:️ [bold red]Please keep this token in a safe place!',
         )
         table.add_row(':eyes: Visibility', visibility)
-        table.add_row(':whale: DockerHub', f'https://hub.docker.com/r/jinahub/{uuid8}/')
-        console.print(table)
 
-        presented_id = image.get('alias', uuid8)
+        p1 = Panel(
+            table,
+            title='Published',
+            width=80,
+            expand=False,
+        )
+
+        console.print(p1)
+
+        presented_id = image.get('name', uuid8)
         usage = (
             f'{presented_id}' if visibility == 'public' else f'{presented_id}:{secret}'
-        )
+        ) + (f'/{tag}' if tag else '')
 
         if not self.args.no_usage:
             self._get_prettyprint_usage(console, usage)
 
         return uuid8, secret
 
-    def _get_prettyprint_usage(self, console, usage):
+    def _get_prettyprint_usage(self, console, executor_name, usage_kind=None):
         from rich.panel import Panel
         from rich.syntax import Syntax
 
         flow_plain = f'''from jina import Flow
 
-f = Flow().add(uses='jinahub://{usage}')
+f = Flow().add(uses='jinahub://{executor_name}')
 
 with f:
     ...'''
 
         flow_docker = f'''from jina import Flow
 
-f = Flow().add(uses='jinahub+docker://{usage}')
+f = Flow().add(uses='jinahub+docker://{executor_name}')
 
 with f:
     ...'''
 
-        cli_plain = f'jina executor --uses jinahub://{usage}'
-
-        cli_docker = f'jina executor --uses jinahub+docker://{usage}'
-
         p1 = Panel(
             Syntax(
                 flow_plain, 'python', theme='monokai', line_numbers=True, word_wrap=True
             ),
-            title='Flow usage',
+            title='Usage',
             width=80,
             expand=False,
         )
@@ -476,48 +531,38 @@ with f:
                 line_numbers=True,
                 word_wrap=True,
             ),
-            title='Flow usage via Docker',
+            title='Docker usage',
             width=80,
             expand=False,
         )
 
-        p3 = Panel(
-            Syntax(
-                cli_plain, 'console', theme='monokai', line_numbers=True, word_wrap=True
-            ),
-            title='CLI usage',
-            width=80,
-            expand=False,
-        )
-        p4 = Panel(
-            Syntax(
-                cli_docker,
-                'console',
-                theme='monokai',
-                line_numbers=True,
-                word_wrap=True,
-            ),
-            title='CLI usage via Docker',
-            width=80,
-            expand=False,
-        )
-
-        console.print(p1, p2, p3, p4)
+        if usage_kind == 'docker':
+            console.print(p2)
+        elif usage_kind == 'source':
+            console.print(p1)
+        else:
+            console.print(p1, p2)
 
     @staticmethod
     @disk_cache_offline(cache_file=str(_cache_file))
-    def _fetch_meta(
+    def fetch_meta(
         name: str,
-        tag: Optional[str] = None,
+        tag: str,
         secret: Optional[str] = None,
+        force: bool = False,
     ) -> HubExecutor:
         """Fetch the executor meta info from Jina Hub.
-        :param name: the UUID/Alias of the executor
-        :param tag: the version tag of the executor
+        :param name: the UUID/Name of the executor
+        :param tag: the tag of the executor if available, otherwise, use `None` as the value
         :param secret: the access secret of the executor
+        :param force: if set to True, access to fetch_meta will always pull latest Executor metas, otherwise, default
+            to local cache
         :return: meta of executor
-        """
 
+        .. note::
+            The `name` and `tag` should be passed via ``args`` and `force` and `secret` as ``kwargs``, otherwise,
+            cache does not work.
+        """
         with ImportExtensions(required=True):
             import requests
 
@@ -540,109 +585,195 @@ with f:
 
         return HubExecutor(
             uuid=resp['id'],
-            alias=resp.get('alias', None),
+            name=resp.get('name', None),
             sn=resp.get('sn', None),
-            tag=resp['tag'],
+            tag=tag or resp['tag'],
             visibility=resp['visibility'],
             image_name=resp['image'],
             archive_url=resp['package']['download'],
             md5sum=resp['package']['md5'],
         )
 
+    def _pull_with_progress(self, log_streams, console):
+        from rich.progress import Progress, DownloadColumn, BarColumn
+
+        with Progress(
+            "[progress.description]{task.description}",
+            BarColumn(),
+            DownloadColumn(),
+            "[progress.percentage]{task.percentage:>3.0f}%",
+            console=console,
+            transient=True,
+        ) as progress:
+            tasks = {}
+            for log in log_streams:
+                if 'status' not in log:
+                    continue
+                status = log['status']
+                status_id = log.get('id', None)
+                pg_detail = log.get('progressDetail', None)
+
+                if (pg_detail is None) or (status_id is None):
+                    self.logger.debug(status)
+                    continue
+
+                if status_id not in tasks:
+                    tasks[status_id] = progress.add_task(status, total=0)
+
+                task_id = tasks[status_id]
+
+                if ('current' in pg_detail) and ('total' in pg_detail):
+                    progress.update(
+                        task_id,
+                        completed=pg_detail['current'],
+                        total=pg_detail['total'],
+                        description=status,
+                    )
+                elif not pg_detail:
+                    progress.update(task_id, advance=0, description=status)
+
+    def _load_docker_client(self):
+        with ImportExtensions(required=True):
+            import docker.errors
+            import docker
+            from docker import APIClient
+
+            from .. import __windows__
+
+            try:
+                self._client = docker.from_env()
+                # low-level client
+                self._raw_client = APIClient(
+                    base_url=docker.constants.DEFAULT_NPIPE
+                    if __windows__
+                    else docker.constants.DEFAULT_UNIX_SOCKET
+                )
+            except docker.errors.DockerException:
+                self.logger.critical(
+                    f'Docker daemon seems not running. Please run Docker daemon and try again.'
+                )
+                exit(1)
+
     def pull(self) -> str:
         """Pull the executor package from Jina Hub.
 
         :return: the `uses` string
         """
-        from rich.console import Console
 
-        with ImportExtensions(required=True):
-            import docker
+        from rich.console import Console
 
         console = Console()
         cached_zip_file = None
-        usage = None
+        executor_name = None
+        usage_kind = None
 
-        with console.status(f'Pulling {self.args.uri}...') as st:
-            try:
+        try:
+            need_pull = self.args.force_update
+            with console.status(f'Pulling {self.args.uri}...') as st:
                 scheme, name, tag, secret = parse_hub_uri(self.args.uri)
 
-                st.update(f'Fetching meta data of {name}...')
-                executor = HubIO._fetch_meta(name, tag=tag, secret=secret)
-                usage = (
-                    f'{executor.uuid}'
+                st.update(f'Fetching [bold]{name}[/bold] from Jina Hub ...')
+                executor = HubIO.fetch_meta(name, tag, secret=secret, force=need_pull)
+
+                presented_id = getattr(executor, 'name', executor.uuid)
+                executor_name = (
+                    f'{presented_id}'
                     if executor.visibility == 'public'
-                    else f'{executor.uuid}:{secret}'
-                )
+                    else f'{presented_id}:{secret}'
+                ) + (f'/{tag}' if tag else '')
 
                 if scheme == 'jinahub+docker':
                     self._load_docker_client()
-                    st.update(f'Pulling {executor.image_name}...')
-                    try:
-                        self._client.images.pull(executor.image_name)
-                    except docker.errors.APIError as api_exc:
-                        try:
-                            self._client.images.get(executor.image_name)
-                        except docker.errors.ImageNotFound:
-                            raise api_exc
+                    import docker
 
+                    try:
+                        self._client.images.get(executor.image_name)
+                    except docker.errors.ImageNotFound:
+                        need_pull = True
+
+                    if need_pull:
+                        st.update(f'Pulling image ...')
+                        log_stream = self._raw_client.pull(
+                            executor.image_name, stream=True, decode=True
+                        )
+                        st.stop()
+                        self._pull_with_progress(
+                            log_stream,
+                            console,
+                        )
+                    usage_kind = 'docker'
                     return f'docker://{executor.image_name}'
                 elif scheme == 'jinahub':
                     import filelock
 
                     with filelock.FileLock(get_lockfile(), timeout=-1):
                         try:
-                            pkg_path, pkg_dist_path = resolve_local(executor)
+                            pkg_path, pkg_dist_path = get_dist_path_of_executor(
+                                executor
+                            )
                             # check serial number to upgrade
                             sn_file_path = pkg_dist_path / f'PKG-SN-{executor.sn or 0}'
-                            if not sn_file_path.exists() and any(
-                                True for _ in pkg_dist_path.glob('PKG-SN-*')
+                            if (not sn_file_path.exists()) and any(
+                                pkg_dist_path.glob('PKG-SN-*')
                             ):
                                 raise FileNotFoundError(
                                     f'{pkg_path} need to be upgraded'
                                 )
-                            if self.args.install_requirements:
-                                requirements_file = pkg_dist_path / 'requirements.txt'
-                                if requirements_file.exists():
-                                    install_requirements(requirements_file)
-                            return f'{pkg_path / "config.yml"}'
-                        except FileNotFoundError:
-                            pass  # have not been downloaded yet, download for the first time
-                        # download the package
-                        cache_dir = Path(
-                            os.environ.get(
-                                'JINA_HUB_CACHE_DIR',
-                                Path.home().joinpath('.cache', 'jina'),
+
+                            st.update('Installing [bold]requirements.txt[/bold]...')
+                            install_package_dependencies(
+                                install_deps=self.args.install_requirements,
+                                pkg_dist_path=pkg_dist_path,
+                                pkg_path=pkg_dist_path,
                             )
-                        )
-                        cache_dir.mkdir(parents=True, exist_ok=True)
 
-                        st.update(f'Downloading {name}...')
-                        cached_zip_file = download_with_resume(
-                            executor.archive_url,
-                            cache_dir,
-                            f'{executor.uuid}-{executor.md5sum}.zip',
-                            md5sum=executor.md5sum,
-                        )
+                        except FileNotFoundError:
+                            need_pull = True
 
-                        st.update(f'Unpacking {name}...')
-                        install_local(
-                            cached_zip_file,
-                            executor,
-                            install_deps=self.args.install_requirements,
-                        )
+                        if need_pull:
+                            # pull the latest executor meta, as the cached data would expire
+                            executor = HubIO.fetch_meta(
+                                name, tag, secret=secret, force=True
+                            )
 
-                        pkg_path, _ = resolve_local(executor)
+                            cache_dir = Path(
+                                os.environ.get(
+                                    'JINA_HUB_CACHE_DIR',
+                                    Path.home().joinpath('.cache', 'jina'),
+                                )
+                            )
+                            cache_dir.mkdir(parents=True, exist_ok=True)
+
+                            st.update(f'Downloading {name} ...')
+                            cached_zip_file = download_with_resume(
+                                executor.archive_url,
+                                cache_dir,
+                                f'{executor.uuid}-{executor.md5sum}.zip',
+                                md5sum=executor.md5sum,
+                            )
+
+                            st.update(f'Unpacking {name} ...')
+                            install_local(
+                                cached_zip_file,
+                                executor,
+                                install_deps=self.args.install_requirements,
+                            )
+
+                            pkg_path, _ = get_dist_path_of_executor(executor)
+
+                        usage_kind = 'source'
                         return f'{pkg_path / "config.yml"}'
                 else:
                     raise ValueError(f'{self.args.uri} is not a valid scheme')
-            except Exception as e:
-                self.logger.error(f'Error while pulling {self.args.uri}: \n{e!r}')
-                raise e
-            finally:
-                # delete downloaded zip package if existed
-                if cached_zip_file is not None:
-                    cached_zip_file.unlink()
+        except KeyboardInterrupt:
+            executor_name = None
+        except Exception:
+            executor_name = None
+            raise
+        finally:
+            # delete downloaded zip package if existed
+            if cached_zip_file is not None:
+                cached_zip_file.unlink()
 
-                if not self.args.no_usage and usage:
-                    self._get_prettyprint_usage(console, usage)
+            if not self.args.no_usage and executor_name:
+                self._get_prettyprint_usage(console, executor_name, usage_kind)
