@@ -102,3 +102,22 @@ When not given, then the default naming strategy will apply.
         type=str,
         help='Routing graph for the gateway' if _SHOW_ALL_ARGS else argparse.SUPPRESS,
     )
+
+    parser.add_argument(
+        '--dynamic-routing',
+        action='store_true',
+        default=True,
+        help='The Pod will setup the socket types of the HeadPea and TailPea depending on this argument.'
+        if _SHOW_ALL_ARGS
+        else argparse.SUPPRESS,
+    )
+
+    parser.add_argument(
+        '--extra-search-paths',
+        type=str,
+        default=[],
+        nargs='*',
+        help='Extra search paths to be used when loading modules and finding YAML config files.'
+        if _SHOW_ALL_ARGS
+        else argparse.SUPPRESS,
+    )
