@@ -1,5 +1,4 @@
-import pprint
-from typing import Dict
+from typing import Dict, Tuple
 
 from google.protobuf.json_format import MessageToJson, MessageToDict
 
@@ -15,14 +14,22 @@ class ProtoTypeMixin:
 
         :return: JSON string of the object
         """
-        return MessageToJson(self._pb_body)
+        return MessageToJson(
+            self._pb_body, preserving_proto_field_name=True, sort_keys=True
+        )
 
     def dict(self) -> Dict:
         """Return the object in Python dictionary
 
         :return: dict representation of the object
         """
-        return MessageToDict(self._pb_body)
+
+        # NOTE: PLEASE DO NOT ADD `including_default_value_fields`,
+        # it makes the output very verbose!
+        return MessageToDict(
+            self._pb_body,
+            preserving_proto_field_name=True,
+        )
 
     @property
     def proto(self) -> 'jina_pb2._reflection.GeneratedProtocolMessageType':
@@ -32,34 +39,33 @@ class ProtoTypeMixin:
         """
         return self._pb_body
 
-    @property
     def binary_str(self) -> bytes:
         """Return the serialized the message to a string.
 
         :return: binary string representation of the object
         """
-        return self._pb_body.SerializeToString()
+        return self._pb_body.SerializePartialToString()
+
+    @property
+    def nbytes(self) -> int:
+        """Return total bytes consumed by protobuf.
+
+        :return: number of bytes
+        """
+        return len(self.binary_str())
 
     def __getattr__(self, name: str):
         return getattr(self._pb_body, name)
 
-    def __str__(self):
-        return str(self._build_content_dict())
-
     def __repr__(self):
-        content = ' '.join(f'{k}={v}' for k, v in self._build_content_dict().items())
+        content = str(self.non_empty_fields)
         content += f' at {id(self)}'
-        content = content.strip()
-        return f'<{typename(self)} {content}>'
+        return f'<{typename(self)} {content.strip()}>'
 
-    def _build_content_dict(self):
-        """Helper method for __str__ and __repr__
+    @property
+    def non_empty_fields(self) -> Tuple[str, ...]:
+        """Return the set fields of the current Protobuf message that are not empty
 
-        :return: the dict representation for the object
+        :return: the tuple of non-empty fields
         """
-        content = self.dict()
-        if hasattr(self, '_attributes_in_str') and isinstance(
-            self._attributes_in_str, list
-        ):
-            content = {k: content[k] for k in self._attributes_in_str}
-        return content
+        return tuple(field[0].name for field in self.ListFields())
