@@ -16,9 +16,9 @@ class DenseNdArray(BaseDenseNdArray):
     Most of the cases you don't want use this class directly, use :class:`NdArray` instead.
 
     :param proto: the protobuf message, when not given then create a new one
-    :param quantize: the quantization method used when converting to protobuf.
-    :param args:  Additional positional arguments
-    :param kwargs: Additional keyword arguments
+    :param dtype: the dtype used when stored as protobuf message.
+    :param args: Additional positional arguments which are just used for the parent initialization
+    :param kwargs: Additional keyword arguments which are just used for the parent initialization
         Availables are ``fp16``, ``uint8``, default is None.
 
     .. note::
@@ -35,13 +35,13 @@ class DenseNdArray(BaseDenseNdArray):
 
     def __init__(
         self,
-        proto: 'jina_pb2.NdArrayProto' = None,
-        quantize: Optional[str] = None,
+        proto: Optional['jina_pb2.NdArrayProto'] = None,
+        dtype: Optional[str] = None,
         *args,
         **kwargs
     ):
         super().__init__(proto, *args, **kwargs)
-        self.quantize = os.environ.get('JINA_ARRAY_QUANT', quantize)
+        self._dtype = dtype or os.environ.get('JINA_ARRAY_QUANT')
 
     @property
     def value(self) -> 'np.ndarray':
@@ -60,6 +60,8 @@ class DenseNdArray(BaseDenseNdArray):
                 x = x.astype(blob.original_dtype) * blob.scale + blob.min_val
 
             return x.reshape(blob.shape)
+        elif len(blob.shape) > 0:
+            return np.zeros(blob.shape)
 
     @value.setter
     def value(self, value: 'np.ndarray'):
@@ -71,11 +73,15 @@ class DenseNdArray(BaseDenseNdArray):
         blob = self._pb_body
         x = value
 
-        if self.quantize == 'fp16' and (x.dtype == np.float32 or x.dtype == np.float64):
+        if self._dtype == 'fp32' and x.dtype == np.float64:
+            blob.quantization = jina_pb2.DenseNdArrayProto.FP32
+            blob.original_dtype = x.dtype.name
+            x = x.astype(np.float32)
+        elif self._dtype == 'fp16' and (x.dtype == np.float32 or x.dtype == np.float64):
             blob.quantization = jina_pb2.DenseNdArrayProto.FP16
             blob.original_dtype = x.dtype.name
             x = x.astype(np.float16)
-        elif self.quantize == 'uint8' and (
+        elif self._dtype == 'uint8' and (
             x.dtype == np.float32 or x.dtype == np.float64 or x.dtype == np.float16
         ):
             blob.quantization = jina_pb2.DenseNdArrayProto.UINT8
